==> openGion6.7.6.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2017/01/05 15:19:07                                            */
/****************************************************************************/

CREATE TABLE GE80 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR (   20 )        DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*  30 FAQ区分      */
 , QANO         VARCHAR (   20 )                    NOT NULL            /*  40 質問番号     */
 , CDBNRUI      VARCHAR (   10 )                                        /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      VARCHAR (  200 )                                        /*  60 関連画面ID   */
 , TITLE        VARCHAR (  300 )                                        /*  70 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR ( 4000 )                                        /*  80 内容         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  90 表示順       */
 , TAG          VARCHAR (  200 )                                        /* 100 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE80S.sql <==
/****************************************************************************/
/* GE80 ( FAQﾃｰﾌﾞﾙ )                                                        */
/*                                                                          */
/* Created : 2018/09/28 16:03:31                                            */
/****************************************************************************/

CREATE TABLE GE80 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR (   20 )        DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , KBFAQ        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /*  30 FAQ区分      */
 , QANO         VARCHAR (   20 )                    NOT NULL            /*  40 質問番号     */
 , CDBNRUI      VARCHAR (   10 )                                        /*  50 分類ｺｰﾄﾞ     */
 , KNRNGUI      VARCHAR (  200 )                                        /*  60 関連画面ID   */
 , TITLE        VARCHAR (  300 )                                        /*  70 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR ( 4000 )                                        /*  80 内容         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  90 表示順       */
 , FILE1        VARCHAR (  200 )                                        /* 100 ﾌｧｲﾙ1        */
 , FILE2        VARCHAR (  200 )                                        /* 110 ﾌｧｲﾙ2        */
 , FILE3        VARCHAR (  200 )                                        /* 120 ﾌｧｲﾙ3        */
 , FILEPATH     VARCHAR (  200 )                                        /* 130 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          VARCHAR (  200 )                                        /* 140 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         SERIAL                                                  /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);
